package com.care.bigscreen.service.impl;


import com.care.bigscreen.mapper.BigSreenMapper;
import com.care.bigscreen.service.BigScreenService;
import com.care.bigscreen.vo.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * @author stw
 * @version 1.0
 * @description 站点统计表接口实现类
 * @date 2021/05/20/19:41
 */
@Service
public class BigScreenServiceImpl implements BigScreenService {

    @Autowired
    private BigSreenMapper bigSreenMapper;

    /**
     * 大屏统计查询
     * @return 搜索符合条件的大屏统计数据
     */
    @Override
    public BigScreenStatisticsVO selectBigScreenStatistics(Long stationId, Long orgId){
        return bigSreenMapper.selectBigScreenStatistics(stationId,orgId);
    }

    /**
     * 大屏统计查询
     * @return 根据经纬度范围搜索符合条件的大屏统计数据
     */
    @Override
    public BigScreenStatisticsVO selectBigScreenStatisticsByLongitudeLatitude(String longitudeLeftUp,String latitudeLeftUp,String longitudeRightDown,String latitudeRightDown,Long orgId) {
        return bigSreenMapper.selectBigScreenStatisticsByLongitudeLatitude(longitudeLeftUp,latitudeLeftUp,longitudeRightDown,latitudeRightDown,orgId);
    }

    /**
     * 站点列表查询
     */
    @Override
    public List<BigScreenStationVO> selectBigScreenStationList(Long orgId) {
        return bigSreenMapper.selectBigScreenStationList(orgId);
    }

    /**
     * 站点列表用户数TOP5查询
     */
    @Override
    public List<BigScreenStationVO> selectBigScreenStationListOlderTop5(Long orgId){
        return bigSreenMapper.selectBigScreenStationListOlderTop5(orgId);
    }

    /**
     * 站点列表安全事件数TOP5查询
     */
    @Override
    public List<BigScreenStationVO> selectBigScreenStationListEventTop5(Long orgId){
        return bigSreenMapper.selectBigScreenStationListEventTop5(orgId);
    }

    /**
     * 服务站大屏的站点统计查询
     * @return 搜索符合条件的大屏统计数据
     */
    @Override
    public BigScreenStationStatisticsVO selectStationBigScreenStatisticsByStation(Long stationId){
        return bigSreenMapper.selectStationBigScreenStatisticsByStation(stationId);
    }

    /**
     * 告警用户列表查询
     */
    @Override
    public List<BigScreenAlarmOlderVO> selectBigScreenAlarmOlderList(Long stationId){
        return bigSreenMapper.selectBigScreenAlarmOlderList(stationId);
    }

    /**
     * 服务站大屏的被监控人详细查询
     */
    @Override
    public BigScreenOlderDetailVO selectStationBigScreenOlderDetail(Long olderId) {
        return bigSreenMapper.selectStationBigScreenOlderDetail(olderId);
    }
}
